<?php

if ( ! class_exists( 'Ppvwc_Metabox' ) ) :

    class Ppvwc_Metabox {

        public $ppvwc_object;

        /**
         * Ppvwc_Metabox constructor.
         * @since 2.0
         * @version 2.1
         */
        public function __construct() {
            add_action( 'add_meta_boxes', array( $this, 'add_meta_box' ), 10, 2 );
            add_action( 'save_post', array( $this, 'save_post' ), 10, 3 );
        }

        /**
         * Add meta box for specific post types.
         *
         * @param string $post_type Post type.
         * @param WP_Post $post Current post object.
         * @since 2.0
         * @version 2.1
         */
        public function add_meta_box( $post_type, $post ) {
            if ( in_array( $post_type, array( 'post', 'page', 'product' ), true ) ) {
                add_meta_box(
                    'ppvwc-metabox',
                    'Views Counter',
                    array( $this, 'metabox_callback' ),
                    $post_type,
                    'side',
                    'default'
                );
            }
        }

        /**
         * Render the meta box.
         *
         * @since 2.0
         * @version 2.1
         */
        public function metabox_callback() {
            $views = (int) ppvwc_get_views();

            // Add a nonce field for security.
            wp_nonce_field( 'ppvwc_save_meta_box', 'ppvwc_meta_box_nonce' );

            echo '
                <label for="views-counts">' . esc_html__( 'Views Counts', 'posts-and-products-views' ) . '</label>
                <input type="number" id="views-counts" name="ppvwc_counts" value="' . esc_attr( $views ) . '" />
            ';
        }

        /**
         * Save post meta when the post is saved.
         *
         * @param int $post_ID Post ID.
         * @param WP_Post $post Post object.
         * @param bool $update Whether this is an update.
         * @since 2.0
         * @version 2.1
         */
        public function save_post( $post_ID, $post, $update ) {
            // Verify nonce for security.
            if ( ! isset( $_POST['ppvwc_meta_box_nonce'] ) || 
                 ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['ppvwc_meta_box_nonce'] ) ), 'ppvwc_save_meta_box' ) ) {
                return;
            }

            // Check user permissions.
            if ( ! current_user_can( 'edit_post', $post_ID ) ) {
                return;
            }

            // Check if it's a valid post type.
            if ( ! in_array( $post->post_type, array( 'post', 'page', 'product' ), true ) ) {
                return;
            }

            // Validate and sanitize the input.
            if ( isset( $_POST['ppvwc_counts'] ) ) {
                $views = sanitize_text_field( wp_unslash( $_POST['ppvwc_counts'] ) );
                $views = (int) $views;

                update_post_meta( $post_ID, 'papvfwc_counter', $views );
            }
        }
    }

    new Ppvwc_Metabox();

endif;
